@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -29,9 +29,18 @@ FAILEDOPERATION_BUILDAUTHTOKEN = 'FailedOperation.BuildAuthToken'
 # CIC的身份提供商禁止操作
 FAILEDOPERATION_CICIDENTITYFORBIDDEN = 'FailedOperation.CICIdentityForbidden'
 
+# 存在高风险操作。
+FAILEDOPERATION_EXISTHIGHRISKOPERATIONS = 'FailedOperation.ExistHighRiskOperations'
+
 # 凭据操作失败。
 FAILEDOPERATION_FLOWAUTHILLEGAL = 'FailedOperation.FlowAuthIllegal'
 
+# 禁止当前用户创建子账号。
+FAILEDOPERATION_FORBIDADD = 'FailedOperation.ForbidAdd'
+
+# 获取用户地域信息失败
+FAILEDOPERATION_GETUSERAREAERROR = 'FailedOperation.GetUserAreaError'
+
 # 集团策略不允许操作。
 FAILEDOPERATION_ORGANIZATIONPOLICYOPERATEERROR = 'FailedOperation.OrganizationPolicyOperateError'
 
@@ -302,6 +311,9 @@ LIMITEXCEEDED_UIN = 'LimitExceeded.Uin'
 # 每个账号最多支持两个AccessKey。
 OPERATIONDENIED_ACCESSKEYOVERLIMIT = 'OperationDenied.AccessKeyOverLimit'
 
+# 禁止变更 CIC Policy。
+OPERATIONDENIED_CICPOLICYOPERATIONDENIED = 'OperationDenied.CicPolicyOperationDenied'
+
 # 存在未删除的API密钥。
 OPERATIONDENIED_HAVEKEYS = 'OperationDenied.HaveKeys'
 
