@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -46,7 +46,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def AddCdnDomain(self, request):
@@ -69,7 +69,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateClsLogTopic(self, request):
@@ -92,11 +92,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateDiagnoseUrl(self, request):
-        """CreateDiagnoseUrl 用于添加域名诊断任务URL， <font color=red>将于 **2023年5月31日** 下线</font><br>
+        """### <font color=red>**该接口已废弃** </font><br>
+        CreateDiagnoseUrl 用于添加域名诊断任务URL。
 
         :param request: Request instance for CreateDiagnoseUrl.
         :type request: :class:`tencentcloud.cdn.v20180606.models.CreateDiagnoseUrlRequest`
@@ -115,7 +116,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateEdgePackTask(self, request):
@@ -138,11 +139,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateScdnDomain(self, request):
-        """CreateScdnDomain 用于创建 SCDN 加速域名
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        CreateScdnDomain 用于创建 SCDN 加速域名
 
         :param request: Request instance for CreateScdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnDomainRequest`
@@ -161,11 +164,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateScdnFailedLogTask(self, request):
-        """CreateScdnFailedLogTask 用于重试创建失败的事件日志任务
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        CreateScdnFailedLogTask 用于重试创建失败的事件日志任务
 
         :param request: Request instance for CreateScdnFailedLogTask.
         :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnFailedLogTaskRequest`
@@ -184,11 +189,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateScdnLogTask(self, request):
-        """CreateScdnLogTask 用于创建事件日志任务
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        CreateScdnLogTask 用于创建事件日志任务
 
         :param request: Request instance for CreateScdnLogTask.
         :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnLogTaskRequest`
@@ -207,7 +214,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateVerifyRecord(self, request):
@@ -233,7 +240,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteCdnDomain(self, request):
@@ -256,7 +263,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteClsLogTopic(self, request):
@@ -279,11 +286,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteScdnDomain(self, request):
-        """删除SCDN域名
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        删除SCDN域名
 
         :param request: Request instance for DeleteScdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DeleteScdnDomainRequest`
@@ -302,7 +311,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeBillingData(self, request):
@@ -325,11 +334,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCcData(self, request):
-        """CC统计数据查询
+        """SCDN平台下线，接口开始预下线处理
+
+        CC统计数据查询
 
         :param request: Request instance for DescribeCcData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeCcDataRequest`
@@ -348,7 +359,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCdnData(self, request):
@@ -383,7 +394,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCdnDomainLogs(self, request):
@@ -406,7 +417,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCdnIp(self, request):
@@ -430,11 +441,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCdnOriginIp(self, request):
-        """本接口（DescribeCdnOriginIp）用于查询 CDN 回源节点的IP信息。（注：此接口即将下线，不再进行维护，请通过DescribeIpStatus 接口进行查询）
+        """### <font color=red>**该接口已废弃** </font><br>
+        本接口（DescribeCdnOriginIp）用于查询 CDN 回源节点的IP信息。（注：替换接口为DescribeIpStatus）
 
         :param request: Request instance for DescribeCdnOriginIp.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeCdnOriginIpRequest`
@@ -453,7 +465,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeCertDomains(self, request):
@@ -476,11 +488,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDDoSData(self, request):
-        """DDoS统计数据查询
+        """SCDN平台下线，接口开始预下线处理
+
+        DDoS统计数据查询
 
         :param request: Request instance for DescribeDDoSData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDDoSDataRequest`
@@ -499,11 +513,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDiagnoseReport(self, request):
-        """DescribeDiagnoseReport 用于获取指定报告id的内容， <font color=red>将于 **2023年5月31日** 下线</font><br>
+        """### <font color=red>**该接口已废弃** </font><br>
+        DescribeDiagnoseReport 用于获取指定报告id的内容。
 
         :param request: Request instance for DescribeDiagnoseReport.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDiagnoseReportRequest`
@@ -522,12 +537,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDistrictIspData(self, request):
         """查询指定域名的区域、运营商明细数据
-        注意事项：接口尚未全量开放，未在内测名单中的账号不支持调用
+        注意事项：接口尚未全面开放，未在内测名单中的账号不支持调用
 
         :param request: Request instance for DescribeDistrictIspData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeDistrictIspDataRequest`
@@ -546,7 +561,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDomains(self, request):
@@ -569,7 +584,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeDomainsConfig(self, request):
@@ -592,7 +607,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeEdgePackTaskStatus(self, request):
@@ -615,11 +630,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeEventLogData(self, request):
-        """DescribeEventLogData 用于查询事件日志统计曲线
+        """SCDN平台下线，接口开始预下线处理
+
+        DescribeEventLogData 用于查询事件日志统计曲线
 
         :param request: Request instance for DescribeEventLogData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeEventLogDataRequest`
@@ -638,7 +655,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeHttpsPackages(self, request):
@@ -661,7 +678,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeImageConfig(self, request):
@@ -684,7 +701,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeIpStatus(self, request):
@@ -709,7 +726,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeIpVisit(self, request):
@@ -735,7 +752,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeMapInfo(self, request):
@@ -758,7 +775,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeOriginData(self, request):
@@ -791,7 +808,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePayType(self, request):
@@ -814,7 +831,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePurgeQuota(self, request):
@@ -837,7 +854,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePurgeTasks(self, request):
@@ -860,7 +877,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePushQuota(self, request):
@@ -883,7 +900,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribePushTasks(self, request):
@@ -906,7 +923,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeReportData(self, request):
@@ -929,11 +946,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeScdnBotData(self, request):
-        """获取BOT统计数据列表
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        获取BOT统计数据列表
 
         :param request: Request instance for DescribeScdnBotData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotDataRequest`
@@ -952,11 +971,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeScdnBotRecords(self, request):
-        """查询BOT会话记录列表
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        查询BOT会话记录列表
 
         :param request: Request instance for DescribeScdnBotRecords.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnBotRecordsRequest`
@@ -975,11 +996,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeScdnConfig(self, request):
-        """DescribeScdnConfig 用于查询指定 SCDN 加速域名的安全相关配置
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        DescribeScdnConfig 用于查询指定 SCDN 加速域名的安全相关配置
 
         :param request: Request instance for DescribeScdnConfig.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnConfigRequest`
@@ -998,11 +1021,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeScdnIpStrategy(self, request):
-        """查询在SCDN IP安全策略
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        查询在SCDN IP安全策略
 
         :param request: Request instance for DescribeScdnIpStrategy.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnIpStrategyRequest`
@@ -1021,11 +1046,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeScdnTopData(self, request):
-        """获取SCDN的Top数据
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        获取SCDN的Top数据
 
         :param request: Request instance for DescribeScdnTopData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnTopDataRequest`
@@ -1044,7 +1071,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTopData(self, request):
@@ -1058,7 +1085,6 @@ class CdnClient(AbstractClient):
 
         注意：
         + 仅支持 90 天内数据查询，且从2021年09月20日开始有数据
-        + 本接口为beta版，尚未正式全量发布
 
         :param request: Request instance for DescribeTopData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeTopDataRequest`
@@ -1077,7 +1103,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTrafficPackages(self, request):
@@ -1100,12 +1126,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeUrlViolations(self, request):
         """DescribeUrlViolations 用于查询被 CDN 系统扫描到的域名违规 URL 列表及当前状态。
-        对应内容分发网络控制台【图片鉴黄】页面。
+        对应内容分发网络控制台【内容合规】页面。
 
         :param request: Request instance for DescribeUrlViolations.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeUrlViolationsRequest`
@@ -1124,11 +1150,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeWafData(self, request):
-        """Waf统计数据查询
+        """SCDN平台下线，接口开始预下线处理
+
+        Waf统计数据查询
 
         :param request: Request instance for DescribeWafData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeWafDataRequest`
@@ -1147,11 +1175,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DisableCaches(self, request):
-        """DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，中国境内访问会直接返回 403。（注：接口尚在内测中，暂未全量开放；封禁URL并非无限期永久封禁）
+        """### <font color=red>**该接口已废弃** </font><br>
+        DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，中国境内访问会直接返回 403。
 
         :param request: Request instance for DisableCaches.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DisableCachesRequest`
@@ -1170,7 +1199,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DisableClsLogTopic(self, request):
@@ -1193,7 +1222,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DuplicateDomainConfig(self, request):
@@ -1216,11 +1245,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def EnableCaches(self, request):
-        """EnableCaches 用于解禁手工封禁的 URL，解禁成功后，全网生效时间约 5~10 分钟。（接口尚在内测中，暂未全量开放使用）
+        """### <font color=red>**该接口已废弃** </font><br>
+        EnableCaches 用于解禁手工封禁的 URL，解禁成功后，全网生效时间约 5~10 分钟。
 
         :param request: Request instance for EnableCaches.
         :type request: :class:`tencentcloud.cdn.v20180606.models.EnableCachesRequest`
@@ -1239,7 +1269,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def EnableClsLogTopic(self, request):
@@ -1262,11 +1292,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def GetDisableRecords(self, request):
-        """GetDisableRecords 用于查询资源禁用历史，及 URL 当前状态。（接口尚在内测中，暂未全量开放使用）
+        """### <font color=red>**该接口已废弃** </font><br>
+        GetDisableRecords 用于查询资源禁用历史，及 URL 当前状态。
 
         :param request: Request instance for GetDisableRecords.
         :type request: :class:`tencentcloud.cdn.v20180606.models.GetDisableRecordsRequest`
@@ -1285,7 +1316,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListClsLogTopics(self, request):
@@ -1308,7 +1339,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListClsTopicDomains(self, request):
@@ -1331,11 +1362,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListDiagnoseReport(self, request):
-        """ListDiagnoseReport 用于获取用户诊断URL访问后各个子任务的简要详情， <font color=red>将于 **2023年5月31日** 下线</font><br>
+        """### <font color=red>**该接口已废弃** </font><br>
+        ListDiagnoseReport 用于获取用户诊断URL访问后各个子任务的简要详情。
 
         :param request: Request instance for ListDiagnoseReport.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListDiagnoseReportRequest`
@@ -1354,11 +1386,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListScdnDomains(self, request):
-        """ListScdnDomains 用于查询 SCDN 安全加速域名列表，及域名基本配置信息
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        ListScdnDomains 用于查询 SCDN 安全加速域名列表，及域名基本配置信息
 
         :param request: Request instance for ListScdnDomains.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListScdnDomainsRequest`
@@ -1377,11 +1411,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListScdnLogTasks(self, request):
-        """ListScdnLogTasks 用于查询SCDN日志下载任务列表,以及展示下载任务基本信息
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        ListScdnLogTasks 用于查询SCDN日志下载任务列表,以及展示下载任务基本信息
 
         :param request: Request instance for ListScdnLogTasks.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListScdnLogTasksRequest`
@@ -1400,11 +1436,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListScdnTopBotData(self, request):
-        """获取Bot攻击的Top数据列表
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        获取Bot攻击的Top数据列表
 
         :param request: Request instance for ListScdnTopBotData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListScdnTopBotDataRequest`
@@ -1423,11 +1461,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopBotData(self, request):
-        """获取Bot攻击的Top信息
+        """SCDN平台下线，接口开始预下线处理
+
+        获取Bot攻击的Top信息
 
         :param request: Request instance for ListTopBotData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopBotDataRequest`
@@ -1446,11 +1486,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopCcData(self, request):
-        """获取CC攻击Top数据
+        """SCDN平台下线，接口开始预下线处理
+
+        获取CC攻击Top数据
 
         :param request: Request instance for ListTopCcData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopCcDataRequest`
@@ -1469,7 +1511,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopClsLogData(self, request):
@@ -1492,11 +1534,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopDDoSData(self, request):
-        """获取DDoS攻击Top数据
+        """SCDN平台下线，接口开始预下线处理
+
+        获取DDoS攻击Top数据
 
         :param request: Request instance for ListTopDDoSData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopDDoSDataRequest`
@@ -1515,7 +1559,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopData(self, request):
@@ -1546,11 +1590,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ListTopWafData(self, request):
-        """获取Waf攻击Top数据
+        """SCDN平台下线，接口开始预下线处理
+
+        获取Waf攻击Top数据
 
         :param request: Request instance for ListTopWafData.
         :type request: :class:`tencentcloud.cdn.v20180606.models.ListTopWafDataRequest`
@@ -1569,7 +1615,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ManageClsTopicDomains(self, request):
@@ -1592,7 +1638,34 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyDomainConfig(self, request):
+        """ModifyDomainConfig 用于修改内容分发网络加速域名配置信息
+        注意：
+        Route 字段，使用点分隔，最后一段称为叶子节点，非叶子节点配置保持不变；
+        Value 字段，使用 json 进行序列化，其中固定 update 作为 key，配置路径值参考 https://cloud.tencent.com/document/product/228/41116 接口各配置项复杂类型，为配置路径对应复杂类型下的节点。
+        操作审计相关：接口的入参可能包含密钥等敏感信息，所以此接口的入参不会上报到操作审计。
+
+        :param request: Request instance for ModifyDomainConfig.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ModifyDomainConfigRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ModifyDomainConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyDomainConfig", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyDomainConfigResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyPurgeFetchTaskStatus(self, request):
@@ -1615,7 +1688,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PurgePathCache(self, request):
@@ -1639,7 +1712,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PurgeUrlsCache(self, request):
@@ -1663,12 +1736,12 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def PushUrlsCache(self, request):
         """PushUrlsCache 用于将指定 URL 资源列表加载至 CDN 节点，支持指定加速区域预热。
-        默认情况下境内、境外每日预热 URL 限额为各 1000 条，每次最多可提交 500 条。注意：中国境外区域预热，资源默认加载至中国境外边缘节点，所产生的边缘层流量会计入计费流量。
+        默认情况下境内、境外每日预热 URL 限额为各 1000 条，每次最多可提交 500 条 URL，每次提交的数量会消耗配额总数。如：1次提交500条URL全球预热，此时境内、境外预热 URL 各剩余 500条。注意：中国境外区域预热，资源默认加载至中国境外边缘节点。
 
         :param request: Request instance for PushUrlsCache.
         :type request: :class:`tencentcloud.cdn.v20180606.models.PushUrlsCacheRequest`
@@ -1687,7 +1760,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def SearchClsLog(self, request):
@@ -1710,7 +1783,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StartCdnDomain(self, request):
@@ -1733,11 +1806,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StartScdnDomain(self, request):
-        """StartScdnDomain 用于开启域名的安全防护配置
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        StartScdnDomain 用于开启域名的安全防护配置
 
         :param request: Request instance for StartScdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.StartScdnDomainRequest`
@@ -1756,7 +1831,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopCdnDomain(self, request):
@@ -1780,11 +1855,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopScdnDomain(self, request):
-        """StopScdnDomain 用于关闭域名的安全防护配置
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        StopScdnDomain 用于关闭域名的安全防护配置
 
         :param request: Request instance for StopScdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.StopScdnDomainRequest`
@@ -1803,13 +1880,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateDomainConfig(self, request):
-        """UpdateDomainConfig 用于修改内容分发网络加速域名配置信息
-        注意：如果需要更新复杂类型的配置项，必须传递整个对象的所有属性，未传递的属性将使用默认值，建议通过查询接口获取配置属性后，直接修改后传递给本接口。Https配置由于证书的特殊性，更新时不用传递证书和密钥字段。
-        云审计相关：接口的入参可能包含密钥等敏感信息，所以此接口的入参不会上报到云审计。
+        """UpdateDomainConfig 用于修改内容分发网络加速域名配置信息。
+        注意：如果需要更新复杂类型的配置项，必须传递整个对象的所有属性，未传递的属性将使用默认值，建议通过查询接口获取配置属性后，直接修改后传递给本接口。
+        操作审计相关：接口的入参可能包含密钥等敏感信息，所以此接口的入参不会上报到操作审计。
 
         :param request: Request instance for UpdateDomainConfig.
         :type request: :class:`tencentcloud.cdn.v20180606.models.UpdateDomainConfigRequest`
@@ -1828,7 +1905,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateImageConfig(self, request):
@@ -1851,7 +1928,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdatePayType(self, request):
@@ -1874,11 +1951,13 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def UpdateScdnDomain(self, request):
-        """UpdateScdnDomain 用于修改 SCDN 加速域名安全相关配置
+        """SCDN平台已经正式下线，接口开始预下线处理
+
+        UpdateScdnDomain 用于修改 SCDN 加速域名安全相关配置
 
         :param request: Request instance for UpdateScdnDomain.
         :type request: :class:`tencentcloud.cdn.v20180606.models.UpdateScdnDomainRequest`
@@ -1897,7 +1976,7 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def VerifyDomainRecord(self, request):
@@ -1922,4 +2001,4 @@ class CdnClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
