@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,14 +41,16 @@ class CreateWorkspaceRequest(AbstractModel):
         :type Extensions: list of str
         :param _Lifecycle: 工作空间生命周期钩子.  分为三个阶段 init, start, destroy. 分别表示工作空间数据初始化阶段, 工作空间启动阶段, 工作空间关闭阶段.  用户可以自定义 shell 命令. 
         :type Lifecycle: :class:`tencentcloud.cloudstudio.v20230508.models.LifeCycle`
-        :param _AppId: 应用名称
-        :type AppId: int
-        :param _Uin: 用户UIN
-        :type Uin: str
-        :param _UniqVpcId: VPCID
-        :type UniqVpcId: str
-        :param _SubnetId: 子网ID
-        :type SubnetId: str
+        :param _TenantAppId: 应用名称
+        :type TenantAppId: int
+        :param _TenantUin: 用户UIN
+        :type TenantUin: str
+        :param _TenantUniqVpcId: VPCID
+        :type TenantUniqVpcId: str
+        :param _TenantSubnetId: 子网ID
+        :type TenantSubnetId: str
+        :param _Region: 地域
+        :type Region: str
         """
         self._Name = None
         self._Description = None
@@ -58,13 +60,17 @@ class CreateWorkspaceRequest(AbstractModel):
         self._Envs = None
         self._Extensions = None
         self._Lifecycle = None
-        self._AppId = None
-        self._Uin = None
-        self._UniqVpcId = None
-        self._SubnetId = None
+        self._TenantAppId = None
+        self._TenantUin = None
+        self._TenantUniqVpcId = None
+        self._TenantSubnetId = None
+        self._Region = None
 
     @property
     def Name(self):
+        """工作空间名称, 长度限制 2~64
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -73,6 +79,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Description(self):
+        """工作空间描述, 长度限制 0~255
+        :rtype: str
+        """
         return self._Description
 
     @Description.setter
@@ -81,6 +90,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Specs(self):
+        """工作空间规格。Standard: 2C4G, Calculation: 4C8G, Profession: 8C16G. 默认是 Standard。
+        :rtype: str
+        """
         return self._Specs
 
     @Specs.setter
@@ -89,6 +101,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Image(self):
+        """工作空间基础镜像名称, 默认会使用 All In One 镜像, 长度限制 1~255
+        :rtype: str
+        """
         return self._Image
 
     @Image.setter
@@ -97,6 +112,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Repository(self):
+        """Git 仓库. 工作空间启动时会自动克隆该仓库
+        :rtype: :class:`tencentcloud.cloudstudio.v20230508.models.GitRepository`
+        """
         return self._Repository
 
     @Repository.setter
@@ -105,6 +123,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Envs(self):
+        """环境变量. 会被注入到工作空间中
+        :rtype: list of Env
+        """
         return self._Envs
 
     @Envs.setter
@@ -113,6 +134,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Extensions(self):
+        """预装插件. 工作空间启动时, 会自动安装这些插件。长度限制: 0~10
+        :rtype: list of str
+        """
         return self._Extensions
 
     @Extensions.setter
@@ -121,6 +145,9 @@ class CreateWorkspaceRequest(AbstractModel):
 
     @property
     def Lifecycle(self):
+        """工作空间生命周期钩子.  分为三个阶段 init, start, destroy. 分别表示工作空间数据初始化阶段, 工作空间启动阶段, 工作空间关闭阶段.  用户可以自定义 shell 命令. 
+        :rtype: :class:`tencentcloud.cloudstudio.v20230508.models.LifeCycle`
+        """
         return self._Lifecycle
 
     @Lifecycle.setter
@@ -128,36 +155,59 @@ class CreateWorkspaceRequest(AbstractModel):
         self._Lifecycle = Lifecycle
 
     @property
-    def AppId(self):
-        return self._AppId
+    def TenantAppId(self):
+        """应用名称
+        :rtype: int
+        """
+        return self._TenantAppId
 
-    @AppId.setter
-    def AppId(self, AppId):
-        self._AppId = AppId
+    @TenantAppId.setter
+    def TenantAppId(self, TenantAppId):
+        self._TenantAppId = TenantAppId
 
     @property
-    def Uin(self):
-        return self._Uin
+    def TenantUin(self):
+        """用户UIN
+        :rtype: str
+        """
+        return self._TenantUin
 
-    @Uin.setter
-    def Uin(self, Uin):
-        self._Uin = Uin
+    @TenantUin.setter
+    def TenantUin(self, TenantUin):
+        self._TenantUin = TenantUin
 
     @property
-    def UniqVpcId(self):
-        return self._UniqVpcId
+    def TenantUniqVpcId(self):
+        """VPCID
+        :rtype: str
+        """
+        return self._TenantUniqVpcId
 
-    @UniqVpcId.setter
-    def UniqVpcId(self, UniqVpcId):
-        self._UniqVpcId = UniqVpcId
+    @TenantUniqVpcId.setter
+    def TenantUniqVpcId(self, TenantUniqVpcId):
+        self._TenantUniqVpcId = TenantUniqVpcId
 
     @property
-    def SubnetId(self):
-        return self._SubnetId
+    def TenantSubnetId(self):
+        """子网ID
+        :rtype: str
+        """
+        return self._TenantSubnetId
 
-    @SubnetId.setter
-    def SubnetId(self, SubnetId):
-        self._SubnetId = SubnetId
+    @TenantSubnetId.setter
+    def TenantSubnetId(self, TenantSubnetId):
+        self._TenantSubnetId = TenantSubnetId
+
+    @property
+    def Region(self):
+        """地域
+        :rtype: str
+        """
+        return self._Region
+
+    @Region.setter
+    def Region(self, Region):
+        self._Region = Region
 
 
     def _deserialize(self, params):
@@ -178,10 +228,11 @@ class CreateWorkspaceRequest(AbstractModel):
         if params.get("Lifecycle") is not None:
             self._Lifecycle = LifeCycle()
             self._Lifecycle._deserialize(params.get("Lifecycle"))
-        self._AppId = params.get("AppId")
-        self._Uin = params.get("Uin")
-        self._UniqVpcId = params.get("UniqVpcId")
-        self._SubnetId = params.get("SubnetId")
+        self._TenantAppId = params.get("TenantAppId")
+        self._TenantUin = params.get("TenantUin")
+        self._TenantUniqVpcId = params.get("TenantUniqVpcId")
+        self._TenantSubnetId = params.get("TenantSubnetId")
+        self._Region = params.get("Region")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -212,6 +263,9 @@ class CreateWorkspaceResponse(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -220,6 +274,9 @@ class CreateWorkspaceResponse(AbstractModel):
 
     @property
     def Name(self):
+        """工作空间名称
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -228,6 +285,9 @@ class CreateWorkspaceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -261,6 +321,9 @@ class CreateWorkspaceTokenRequest(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -269,6 +332,9 @@ class CreateWorkspaceTokenRequest(AbstractModel):
 
     @property
     def TokenExpiredLimitSec(self):
+        """token过期时间，单位是秒，默认 3600
+        :rtype: int
+        """
         return self._TokenExpiredLimitSec
 
     @TokenExpiredLimitSec.setter
@@ -277,6 +343,9 @@ class CreateWorkspaceTokenRequest(AbstractModel):
 
     @property
     def Policies(self):
+        """token 授权策略，可选值为 workspace-run-only, all。默认为 workspace-run-only
+        :rtype: list of str
+        """
         return self._Policies
 
     @Policies.setter
@@ -318,6 +387,9 @@ class CreateWorkspaceTokenResponse(AbstractModel):
 
     @property
     def Token(self):
+        """访问工作空间临时凭证
+        :rtype: str
+        """
         return self._Token
 
     @Token.setter
@@ -326,6 +398,9 @@ class CreateWorkspaceTokenResponse(AbstractModel):
 
     @property
     def ExpiredTime(self):
+        """token 过期时间
+        :rtype: str
+        """
         return self._ExpiredTime
 
     @ExpiredTime.setter
@@ -334,6 +409,9 @@ class CreateWorkspaceTokenResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -361,6 +439,9 @@ class DescribeConfigRequest(AbstractModel):
 
     @property
     def Name(self):
+        """配置名称
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -388,7 +469,6 @@ class DescribeConfigResponse(AbstractModel):
     def __init__(self):
         r"""
         :param _Data: 配置值
-注意：此字段可能返回 null，表示取不到有效值。
         :type Data: str
         :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -398,6 +478,9 @@ class DescribeConfigResponse(AbstractModel):
 
     @property
     def Data(self):
+        """配置值
+        :rtype: str
+        """
         return self._Data
 
     @Data.setter
@@ -406,6 +489,9 @@ class DescribeConfigResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -441,6 +527,9 @@ class DescribeImagesResponse(AbstractModel):
 
     @property
     def Images(self):
+        """镜像列表
+        :rtype: list of Image
+        """
         return self._Images
 
     @Images.setter
@@ -449,6 +538,9 @@ class DescribeImagesResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -480,6 +572,9 @@ class DescribeWorkspacesRequest(AbstractModel):
 
     @property
     def Name(self):
+        """工作空间名称过滤条件
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -516,6 +611,9 @@ class DescribeWorkspacesResponse(AbstractModel):
 
     @property
     def Data(self):
+        """工作空间列表
+        :rtype: list of WorkspaceStatusInfo
+        """
         return self._Data
 
     @Data.setter
@@ -524,6 +622,9 @@ class DescribeWorkspacesResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -558,6 +659,9 @@ class Env(AbstractModel):
 
     @property
     def Name(self):
+        """环境变量 key
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -566,6 +670,9 @@ class Env(AbstractModel):
 
     @property
     def Value(self):
+        """环境变量 value
+        :rtype: str
+        """
         return self._Value
 
     @Value.setter
@@ -603,6 +710,9 @@ class GitRepository(AbstractModel):
 
     @property
     def Url(self):
+        """Git 仓库地址
+        :rtype: str
+        """
         return self._Url
 
     @Url.setter
@@ -611,6 +721,9 @@ class GitRepository(AbstractModel):
 
     @property
     def Branch(self):
+        """Git 仓库分支名或 Tag 名
+        :rtype: str
+        """
         return self._Branch
 
     @Branch.setter
@@ -651,6 +764,9 @@ class Image(AbstractModel):
 
     @property
     def Name(self):
+        """镜像名称
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -659,6 +775,9 @@ class Image(AbstractModel):
 
     @property
     def Repository(self):
+        """镜像仓库
+        :rtype: str
+        """
         return self._Repository
 
     @Repository.setter
@@ -667,6 +786,9 @@ class Image(AbstractModel):
 
     @property
     def Tags(self):
+        """tag 列表
+        :rtype: list of str
+        """
         return self._Tags
 
     @Tags.setter
@@ -708,6 +830,9 @@ class LifeCycle(AbstractModel):
 
     @property
     def Init(self):
+        """工作空间首次初始化时执行
+        :rtype: list of LifeCycleCommand
+        """
         return self._Init
 
     @Init.setter
@@ -716,6 +841,9 @@ class LifeCycle(AbstractModel):
 
     @property
     def Start(self):
+        """每次工作空间启动时执行
+        :rtype: list of LifeCycleCommand
+        """
         return self._Start
 
     @Start.setter
@@ -724,6 +852,9 @@ class LifeCycle(AbstractModel):
 
     @property
     def Destroy(self):
+        """每次工作空间关闭时执行
+        :rtype: list of LifeCycleCommand
+        """
         return self._Destroy
 
     @Destroy.setter
@@ -777,6 +908,9 @@ class LifeCycleCommand(AbstractModel):
 
     @property
     def Name(self):
+        """指令描述
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -785,6 +919,9 @@ class LifeCycleCommand(AbstractModel):
 
     @property
     def Command(self):
+        """具体命令
+        :rtype: str
+        """
         return self._Command
 
     @Command.setter
@@ -837,6 +974,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey. 更新该工作空间的属性
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -845,6 +985,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Name(self):
+        """工作空间名称
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -853,6 +996,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Description(self):
+        """工作空间描述
+        :rtype: str
+        """
         return self._Description
 
     @Description.setter
@@ -861,6 +1007,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Specs(self):
+        """工作空间规格。STANDARD: 2C4G, CALCULATION: 4C8G, PROFESSION: 8C16G. 默认是 STANDARD。
+        :rtype: str
+        """
         return self._Specs
 
     @Specs.setter
@@ -869,6 +1018,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Envs(self):
+        """环境变量. 会被注入到工作空间中
+        :rtype: list of Env
+        """
         return self._Envs
 
     @Envs.setter
@@ -877,6 +1029,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Extensions(self):
+        """预装插件. 工作空间启动时, 会自动安装这些插件 
+        :rtype: list of str
+        """
         return self._Extensions
 
     @Extensions.setter
@@ -885,6 +1040,9 @@ class ModifyWorkspaceRequest(AbstractModel):
 
     @property
     def Lifecycle(self):
+        """工作空间生命周期钩子.  分为三个阶段 init, start, destroy. 分别表示工作空间数据初始化阶段, 工作空间启动阶段, 工作空间关闭阶段.  用户可以自定义 shell 命令. 
+        :rtype: :class:`tencentcloud.cloudstudio.v20230508.models.LifeCycle`
+        """
         return self._Lifecycle
 
     @Lifecycle.setter
@@ -931,6 +1089,9 @@ class ModifyWorkspaceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -956,6 +1117,9 @@ class RemoveWorkspaceRequest(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -989,6 +1153,9 @@ class RemoveWorkspaceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1014,6 +1181,9 @@ class RunWorkspaceRequest(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -1047,6 +1217,9 @@ class RunWorkspaceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1072,6 +1245,9 @@ class StopWorkspaceRequest(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间 SpaceKey
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -1105,6 +1281,9 @@ class StopWorkspaceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -1136,28 +1315,20 @@ class WorkspaceStatusInfo(AbstractModel):
         :param _Memory: 内存
         :type Memory: int
         :param _Icon: 工作空间图标
-注意：此字段可能返回 null，表示取不到有效值。
         :type Icon: str
         :param _StatusReason: 工作空间状态, 异常原因
-注意：此字段可能返回 null，表示取不到有效值。
         :type StatusReason: str
         :param _Description: 工作空间描述
-注意：此字段可能返回 null，表示取不到有效值。
         :type Description: str
         :param _WorkspaceType: 工作空间类型
-注意：此字段可能返回 null，表示取不到有效值。
         :type WorkspaceType: str
         :param _VersionControlUrl: Git 仓库 HTTPS 地址
-注意：此字段可能返回 null，表示取不到有效值。
         :type VersionControlUrl: str
         :param _VersionControlRef: Git 仓库引用。指定分支使用 /refs/heads/{分支名}, 指定 Tag 用 /refs/tags/{Tag名}
-注意：此字段可能返回 null，表示取不到有效值。
         :type VersionControlRef: str
         :param _LastOpsDate: 最后操作时间
-注意：此字段可能返回 null，表示取不到有效值。
         :type LastOpsDate: str
         :param _CreateDate: 创建时间
-注意：此字段可能返回 null，表示取不到有效值。
         :type CreateDate: str
         """
         self._Id = None
@@ -1177,6 +1348,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Id(self):
+        """工作空间 ID
+        :rtype: int
+        """
         return self._Id
 
     @Id.setter
@@ -1185,6 +1359,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Name(self):
+        """工作空间名称
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1193,6 +1370,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def SpaceKey(self):
+        """工作空间标识
+        :rtype: str
+        """
         return self._SpaceKey
 
     @SpaceKey.setter
@@ -1201,6 +1381,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Status(self):
+        """工作空间状态
+        :rtype: str
+        """
         return self._Status
 
     @Status.setter
@@ -1209,6 +1392,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Cpu(self):
+        """CPU数量
+        :rtype: int
+        """
         return self._Cpu
 
     @Cpu.setter
@@ -1217,6 +1403,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Memory(self):
+        """内存
+        :rtype: int
+        """
         return self._Memory
 
     @Memory.setter
@@ -1225,6 +1414,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Icon(self):
+        """工作空间图标
+        :rtype: str
+        """
         return self._Icon
 
     @Icon.setter
@@ -1233,6 +1425,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def StatusReason(self):
+        """工作空间状态, 异常原因
+        :rtype: str
+        """
         return self._StatusReason
 
     @StatusReason.setter
@@ -1241,6 +1436,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def Description(self):
+        """工作空间描述
+        :rtype: str
+        """
         return self._Description
 
     @Description.setter
@@ -1249,6 +1447,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def WorkspaceType(self):
+        """工作空间类型
+        :rtype: str
+        """
         return self._WorkspaceType
 
     @WorkspaceType.setter
@@ -1257,6 +1458,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def VersionControlUrl(self):
+        """Git 仓库 HTTPS 地址
+        :rtype: str
+        """
         return self._VersionControlUrl
 
     @VersionControlUrl.setter
@@ -1265,6 +1469,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def VersionControlRef(self):
+        """Git 仓库引用。指定分支使用 /refs/heads/{分支名}, 指定 Tag 用 /refs/tags/{Tag名}
+        :rtype: str
+        """
         return self._VersionControlRef
 
     @VersionControlRef.setter
@@ -1273,6 +1480,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def LastOpsDate(self):
+        """最后操作时间
+        :rtype: str
+        """
         return self._LastOpsDate
 
     @LastOpsDate.setter
@@ -1281,6 +1491,9 @@ class WorkspaceStatusInfo(AbstractModel):
 
     @property
     def CreateDate(self):
+        """创建时间
+        :rtype: str
+        """
         return self._CreateDate
 
     @CreateDate.setter
