@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
 # 未检测到闭眼动作。
 FAILEDOPERATION_ACTIONCLOSEEYE = 'FailedOperation.ActionCloseEye'
 
@@ -47,18 +50,30 @@ FAILEDOPERATION_ACTIONOPENMOUTH = 'FailedOperation.ActionOpenMouth'
 # 比对失败。
 FAILEDOPERATION_COMPAREFAIL = 'FailedOperation.CompareFail'
 
+# 比对库源维护中，暂时不可用
+FAILEDOPERATION_COMPARELIBSERVICEUNAVAILABLE = 'FailedOperation.CompareLibServiceUnavailable'
+
 # 比对相似度未达到通过标准。
 FAILEDOPERATION_COMPARELOWSIMILARITY = 'FailedOperation.CompareLowSimilarity'
 
 # 调用比对引擎接口出错。
 FAILEDOPERATION_COMPARESYSTEMERROR = 'FailedOperation.CompareSystemError'
 
+# The video compression failed. Please try again or reduce the size of the input video.
+FAILEDOPERATION_COMPRESSVIDEOERROR = 'FailedOperation.CompressVideoError'
+
+# 图中人脸存在遮挡，请传入无遮挡人脸图片
+FAILEDOPERATION_COVEREDFACE = 'FailedOperation.CoveredFace'
+
 # 数据库异常。
 FAILEDOPERATION_DBERROR = 'FailedOperation.DbError'
 
 # 解密失败。
 FAILEDOPERATION_DECRYPTSYSTEMERROR = 'FailedOperation.DecryptSystemError'
 
+# 服务引擎调用失败，请重试
+FAILEDOPERATION_DETECTENGINESYSTEMERROR = 'FailedOperation.DetectEngineSystemError'
+
 # 文件下载失败。
 FAILEDOPERATION_DOWNLOADERROR = 'FailedOperation.DownLoadError'
 
@@ -86,12 +101,15 @@ FAILEDOPERATION_IDNOEXISTSYSTEM = 'FailedOperation.IdNoExistSystem'
 # 库中无此号照片，请到户籍所在地进行核实。
 FAILEDOPERATION_IDPHOTONOEXIST = 'FailedOperation.IdPhotoNoExist'
 
-# 证件图片分辨率太低，请重新上传。
+# 证件图片质量差，请更新后重试。
 FAILEDOPERATION_IDPHOTOPOORQUALITY = 'FailedOperation.IdPhotoPoorQuality'
 
 # 客户库自建库或认证中心返照失败，请稍后再试。
 FAILEDOPERATION_IDPHOTOSYSTEMNOANSWER = 'FailedOperation.IdPhotoSystemNoanswer'
 
+# 姓名/身份证号认证次数超过当日限制，请次日重试
+FAILEDOPERATION_IDENTITYAUTHLIMITEXCEEDED = 'FailedOperation.IdentityAuthLimitExceeded'
+
 # 图片模糊。
 FAILEDOPERATION_IMAGEBLUR = 'FailedOperation.ImageBlur'
 
@@ -104,6 +122,9 @@ FAILEDOPERATION_IMAGENOIDCARD = 'FailedOperation.ImageNoIdCard'
 # 图片尺寸过大。
 FAILEDOPERATION_IMAGESIZETOOLARGE = 'FailedOperation.ImageSizeTooLarge'
 
+# 未检测到完整人脸，请传入完整人脸图片
+FAILEDOPERATION_INCOMPLETEFACE = 'FailedOperation.IncompleteFace'
+
 # 检测到多张人脸。
 FAILEDOPERATION_LIFEPHOTODETECTFACES = 'FailedOperation.LifePhotoDetectFaces'
 
@@ -167,6 +188,9 @@ FAILEDOPERATION_NAMEFORMATERROR = 'FailedOperation.NameFormatError'
 # Ocr识别失败。
 FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'
 
+# 图片质量过差，请检查图片质量
+FAILEDOPERATION_POORIMAGEQUALITY = 'FailedOperation.PoorImageQuality'
+
 # 调用次数超出限制。
 FAILEDOPERATION_REQUESTLIMITEXCEEDED = 'FailedOperation.RequestLimitExceeded'
 
@@ -212,6 +236,12 @@ FAILEDOPERATION_UNREGISTEREDEID = 'FailedOperation.UnregisteredEid'
 # 认证不通过。
 FAILEDOPERATION_VERIFICATIONFAIL = 'FailedOperation.VerificationFail'
 
+# 视频解码异常
+FAILEDOPERATION_VIDEODECODEFAILED = 'FailedOperation.VideoDecodeFailed'
+
+# 视频时长过长，当前接口最大支持的视频时长为20s。
+FAILEDOPERATION_VIDEODURATIONEXCEEDED = 'FailedOperation.VideoDurationExceeded'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -257,7 +287,7 @@ UNAUTHORIZEDOPERATION_ACTIVATEERROR = 'UnauthorizedOperation.ActivateError'
 # 服务开通中。
 UNAUTHORIZEDOPERATION_ACTIVATING = 'UnauthorizedOperation.Activating'
 
-# 帐号已欠费。
+# 账号已欠费。
 UNAUTHORIZEDOPERATION_ARREARS = 'UnauthorizedOperation.Arrears'
 
 # 计费状态异常。
