@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -354,6 +354,29 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateUploadTest(self, request):
+        """设备申请cos上传证书
+
+        :param request: Request instance for CreateUploadTest.
+        :type request: :class:`tencentcloud.iotvideo.v20191126.models.CreateUploadTestRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20191126.models.CreateUploadTestResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateUploadTest", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateUploadTestResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateUsrToken(self, request):
         """本接口（CreateUsrToken）用于终端用户获取IoT Video平台的accessToken，初始化SDK,连接到IoT Video接入服务器。
 
@@ -1360,6 +1383,29 @@ class IotvideoClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RenewUploadTest(self, request):
+        """设备刷新cos上传证书
+
+        :param request: Request instance for RenewUploadTest.
+        :type request: :class:`tencentcloud.iotvideo.v20191126.models.RenewUploadTestRequest`
+        :rtype: :class:`tencentcloud.iotvideo.v20191126.models.RenewUploadTestResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RenewUploadTest", params, headers=headers)
+            response = json.loads(body)
+            model = models.RenewUploadTestResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RunDevice(self, request):
         """本接口（RunDevice）用于启用设备，可进行批量操作，每次操作最多100台设备。
 
