@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,22 +25,45 @@ class DismissRoomRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param GameId: 表示游戏资源唯一 ID, 由后台自动分配, 无法修改。
+        :param _GameId: 表示游戏资源唯一 ID, 由后台自动分配, 无法修改。
         :type GameId: str
-        :param RoomId: 表示游戏房间唯一ID。
+        :param _RoomId: 表示游戏房间唯一ID。
         :type RoomId: str
         """
-        self.GameId = None
-        self.RoomId = None
+        self._GameId = None
+        self._RoomId = None
+
+    @property
+    def GameId(self):
+        """表示游戏资源唯一 ID, 由后台自动分配, 无法修改。
+        :rtype: str
+        """
+        return self._GameId
+
+    @GameId.setter
+    def GameId(self, GameId):
+        self._GameId = GameId
+
+    @property
+    def RoomId(self):
+        """表示游戏房间唯一ID。
+        :rtype: str
+        """
+        return self._RoomId
+
+    @RoomId.setter
+    def RoomId(self, RoomId):
+        self._RoomId = RoomId
 
 
     def _deserialize(self, params):
-        self.GameId = params.get("GameId")
-        self.RoomId = params.get("RoomId")
+        self._GameId = params.get("GameId")
+        self._RoomId = params.get("RoomId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
         if len(memeber_set) > 0:
             warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
@@ -53,11 +76,22 @@ class DismissRoomResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :param _RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
-        self.RequestId = None
+        self._RequestId = None
+
+    @property
+    def RequestId(self):
+        """唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
 
 
     def _deserialize(self, params):
-        self.RequestId = params.get("RequestId")
\ No newline at end of file
+        self._RequestId = params.get("RequestId")
\ No newline at end of file
