@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,9 +27,9 @@ class CreateTtsTaskRequest(AbstractModel):
         r"""
         :param _Text: 合成语音的源文本，按UTF-8编码统一计算，最多支持10万字符
         :type Text: str
-        :param _Volume: 音量大小，范围：[-10，10]，分别对应11个等级的音量，默认为0，代表正常音量。没有静音选项。
+        :param _Volume: 音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
         :type Volume: float
-        :param _Speed: 语速，范围：[-2，2]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
+        :param _Speed: 语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
         :type Speed: float
         :param _ProjectId: 项目id，用户自定义，默认为0。
         :type ProjectId: int
@@ -49,7 +49,7 @@ class CreateTtsTaskRequest(AbstractModel):
         :type EnableSubtitle: bool
         :param _VoiceoverDialogueSplit: 旁白与对白文本解析，分别合成相应风格（仅适用于旁对白音色10510000、100510000），默认 false
         :type VoiceoverDialogueSplit: bool
-        :param _EmotionCategory: 控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、撒娇(sajiao)、厌恶(disgusted)、震惊(amaze)、平静(peaceful)、兴奋(exciting)、傲娇(aojiao)、解说(jieshuo)
+        :param _EmotionCategory: 控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
         :type EmotionCategory: str
         :param _EmotionIntensity: 控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效。
         :type EmotionIntensity: int
@@ -71,6 +71,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Text(self):
+        """合成语音的源文本，按UTF-8编码统一计算，最多支持10万字符
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -79,6 +82,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Volume(self):
+        """音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
+        :rtype: float
+        """
         return self._Volume
 
     @Volume.setter
@@ -87,6 +93,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Speed(self):
+        """语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
+        :rtype: float
+        """
         return self._Speed
 
     @Speed.setter
@@ -95,6 +104,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def ProjectId(self):
+        """项目id，用户自定义，默认为0。
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -103,6 +115,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def ModelType(self):
+        """模型类型，1-默认模型。
+        :rtype: int
+        """
         return self._ModelType
 
     @ModelType.setter
@@ -111,6 +126,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def VoiceType(self):
+        """音色 ID，包括标准音色与精品音色，精品音色拟真度更高，价格不同于标准音色，请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+        :rtype: int
+        """
         return self._VoiceType
 
     @VoiceType.setter
@@ -119,6 +137,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def PrimaryLanguage(self):
+        """主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
+        :rtype: int
+        """
         return self._PrimaryLanguage
 
     @PrimaryLanguage.setter
@@ -127,6 +148,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def SampleRate(self):
+        """音频采样率：<li>16000：16k（默认）</li><li>8000：8k</li>
+        :rtype: int
+        """
         return self._SampleRate
 
     @SampleRate.setter
@@ -135,6 +159,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def Codec(self):
+        """返回音频格式，可取值：mp3（默认），wav，pcm
+        :rtype: str
+        """
         return self._Codec
 
     @Codec.setter
@@ -143,6 +170,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def CallbackUrl(self):
+        """回调 URL，用户自行搭建的用于接收识别结果的服务URL。如果用户使用轮询方式获取识别结果，则无需提交该参数。[回调说明](https://cloud.tencent.com/document/product/1073/55746)
+        :rtype: str
+        """
         return self._CallbackUrl
 
     @CallbackUrl.setter
@@ -151,6 +181,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EnableSubtitle(self):
+        """是否开启时间戳功能，默认为false。
+        :rtype: bool
+        """
         return self._EnableSubtitle
 
     @EnableSubtitle.setter
@@ -159,6 +192,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def VoiceoverDialogueSplit(self):
+        """旁白与对白文本解析，分别合成相应风格（仅适用于旁对白音色10510000、100510000），默认 false
+        :rtype: bool
+        """
         return self._VoiceoverDialogueSplit
 
     @VoiceoverDialogueSplit.setter
@@ -167,6 +203,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EmotionCategory(self):
+        """控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
+        :rtype: str
+        """
         return self._EmotionCategory
 
     @EmotionCategory.setter
@@ -175,6 +214,9 @@ class CreateTtsTaskRequest(AbstractModel):
 
     @property
     def EmotionIntensity(self):
+        """控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效。
+        :rtype: int
+        """
         return self._EmotionIntensity
 
     @EmotionIntensity.setter
@@ -221,6 +263,9 @@ class CreateTtsTaskRespData(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务ID，可通过此ID在轮询接口获取合成状态与结果。注意：TaskId数据类型为string
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -257,6 +302,9 @@ class CreateTtsTaskResponse(AbstractModel):
 
     @property
     def Data(self):
+        """任务 id
+        :rtype: :class:`tencentcloud.tts.v20190823.models.CreateTtsTaskRespData`
+        """
         return self._Data
 
     @Data.setter
@@ -265,6 +313,9 @@ class CreateTtsTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -293,6 +344,9 @@ class DescribeTtsTaskStatusRequest(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务id
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -341,6 +395,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def TaskId(self):
+        """任务标识。
+        :rtype: str
+        """
         return self._TaskId
 
     @TaskId.setter
@@ -349,6 +406,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def Status(self):
+        """任务状态码，0：任务等待，1：任务执行中，2：任务成功，3：任务失败。
+        :rtype: int
+        """
         return self._Status
 
     @Status.setter
@@ -357,6 +417,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def StatusStr(self):
+        """任务状态，waiting：任务等待，doing：任务执行中，success：任务成功，failed：任务失败。
+        :rtype: str
+        """
         return self._StatusStr
 
     @StatusStr.setter
@@ -365,6 +428,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def ResultUrl(self):
+        """合成音频COS地址（链接有效期1天）。
+        :rtype: str
+        """
         return self._ResultUrl
 
     @ResultUrl.setter
@@ -373,6 +439,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def Subtitles(self):
+        """时间戳信息，若未开启时间戳，则返回空数组。
+        :rtype: list of Subtitle
+        """
         return self._Subtitles
 
     @Subtitles.setter
@@ -381,6 +450,9 @@ class DescribeTtsTaskStatusRespData(AbstractModel):
 
     @property
     def ErrorMsg(self):
+        """失败原因说明。
+        :rtype: str
+        """
         return self._ErrorMsg
 
     @ErrorMsg.setter
@@ -427,6 +499,9 @@ class DescribeTtsTaskStatusResponse(AbstractModel):
 
     @property
     def Data(self):
+        """任务状态返回
+        :rtype: :class:`tencentcloud.tts.v20190823.models.DescribeTtsTaskStatusRespData`
+        """
         return self._Data
 
     @Data.setter
@@ -435,6 +510,9 @@ class DescribeTtsTaskStatusResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -479,6 +557,9 @@ class Subtitle(AbstractModel):
 
     @property
     def Text(self):
+        """⽂本信息。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -487,6 +568,9 @@ class Subtitle(AbstractModel):
 
     @property
     def BeginTime(self):
+        """⽂本对应tts语⾳开始时间戳，单位ms。
+        :rtype: int
+        """
         return self._BeginTime
 
     @BeginTime.setter
@@ -495,6 +579,9 @@ class Subtitle(AbstractModel):
 
     @property
     def EndTime(self):
+        """⽂本对应tts语⾳结束时间戳，单位ms。
+        :rtype: int
+        """
         return self._EndTime
 
     @EndTime.setter
@@ -503,6 +590,9 @@ class Subtitle(AbstractModel):
 
     @property
     def BeginIndex(self):
+        """该文本在时间戳数组中的开始位置，从0开始。
+        :rtype: int
+        """
         return self._BeginIndex
 
     @BeginIndex.setter
@@ -511,6 +601,9 @@ class Subtitle(AbstractModel):
 
     @property
     def EndIndex(self):
+        """该文本在时间戳数组中的结束位置，从0开始。
+        :rtype: int
+        """
         return self._EndIndex
 
     @EndIndex.setter
@@ -519,6 +612,10 @@ class Subtitle(AbstractModel):
 
     @property
     def Phoneme(self):
+        """该字的音素。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Phoneme
 
     @Phoneme.setter
@@ -563,8 +660,11 @@ class TextToVoiceRequest(AbstractModel):
         :type ProjectId: int
         :param _ModelType: 模型类型，1-默认模型。
         :type ModelType: int
-        :param _VoiceType: 音色 ID，包括标准音色与精品音色，精品音色拟真度更高，价格不同于标准音色，请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+        :param _VoiceType: 音色 ID，包括标准音色、精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+
         :type VoiceType: int
+        :param _FastVoiceType: 一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。【已废弃】
+        :type FastVoiceType: str
         :param _PrimaryLanguage: 主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
         :type PrimaryLanguage: int
         :param _SampleRate: 音频采样率：
@@ -578,13 +678,11 @@ class TextToVoiceRequest(AbstractModel):
         :type EnableSubtitle: bool
         :param _SegmentRate: 断句敏感阈值，默认值为：0，取值范围：[0,1,2]。该值越大越不容易断句，模型会更倾向于仅按照标点符号断句。此参数建议不要随意调整，可能会影响合成效果。
         :type SegmentRate: int
-        :param _EmotionCategory: 控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、撒娇(sajiao)、厌恶(disgusted)、震惊(amaze)、平静(peaceful)、兴奋(exciting)、傲娇(aojiao)、解说(jieshuo)
+        :param _EmotionCategory: 控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
 示例值：neutral
         :type EmotionCategory: str
         :param _EmotionIntensity: 控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效；
         :type EmotionIntensity: int
-        :param _FastVoiceType: 预留参数，暂未使用
-        :type FastVoiceType: str
         """
         self._Text = None
         self._SessionId = None
@@ -593,6 +691,7 @@ class TextToVoiceRequest(AbstractModel):
         self._ProjectId = None
         self._ModelType = None
         self._VoiceType = None
+        self._FastVoiceType = None
         self._PrimaryLanguage = None
         self._SampleRate = None
         self._Codec = None
@@ -600,10 +699,13 @@ class TextToVoiceRequest(AbstractModel):
         self._SegmentRate = None
         self._EmotionCategory = None
         self._EmotionIntensity = None
-        self._FastVoiceType = None
 
     @property
     def Text(self):
+        """合成语音的源文本，按UTF-8编码统一计算。
+中文最大支持150个汉字（全角标点符号算一个汉字）；英文最大支持500个字母（半角标点符号算一个字母）。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -612,6 +714,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SessionId(self):
+        """一次请求对应一个SessionId，会原样返回，建议传入类似于uuid的字符串防止重复。
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -620,6 +725,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Volume(self):
+        """音量大小，范围[-10，10]，对应音量大小。默认为0，代表正常音量，值越大音量越高。
+        :rtype: float
+        """
         return self._Volume
 
     @Volume.setter
@@ -628,6 +736,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Speed(self):
+        """语速，范围：[-2，6]，分别对应不同语速：<li>-2代表0.6倍</li><li>-1代表0.8倍</li><li>0代表1.0倍（默认）</li><li>1代表1.2倍</li><li>2代表1.5倍</li><li>6代表2.5倍</li>如果需要更细化的语速，可以保留小数点后 2 位，例如0.5/1.25/2.81等。<br>参数值与实际语速转换，可参考[代码示例](https://sdk-1300466766.cos.ap-shanghai.myqcloud.com/sample/speed_sample.tar.gz)
+        :rtype: float
+        """
         return self._Speed
 
     @Speed.setter
@@ -636,6 +747,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def ProjectId(self):
+        """项目id，用户自定义，默认为0。
+        :rtype: int
+        """
         return self._ProjectId
 
     @ProjectId.setter
@@ -644,6 +758,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def ModelType(self):
+        """模型类型，1-默认模型。
+        :rtype: int
+        """
         return self._ModelType
 
     @ModelType.setter
@@ -652,14 +769,32 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def VoiceType(self):
+        """音色 ID，包括标准音色、精品音色、大模型音色与基础版复刻音色。不同音色价格有差异，详情请参见[购买指南](https://cloud.tencent.com/document/product/1073/34112)。完整的音色 ID 列表请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)。
+
+        :rtype: int
+        """
         return self._VoiceType
 
     @VoiceType.setter
     def VoiceType(self, VoiceType):
         self._VoiceType = VoiceType
 
+    @property
+    def FastVoiceType(self):
+        """一句话版声音复刻音色ID，使用一句话版声音复刻音色时需填写。【已废弃】
+        :rtype: str
+        """
+        return self._FastVoiceType
+
+    @FastVoiceType.setter
+    def FastVoiceType(self, FastVoiceType):
+        self._FastVoiceType = FastVoiceType
+
     @property
     def PrimaryLanguage(self):
+        """主语言类型：<li>1-中文（默认）</li><li>2-英文</li><li>3-日文</li>
+        :rtype: int
+        """
         return self._PrimaryLanguage
 
     @PrimaryLanguage.setter
@@ -668,6 +803,12 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SampleRate(self):
+        """音频采样率：
+<li>24000：24k（部分音色支持，请参见[音色列表](https://cloud.tencent.com/document/product/1073/92668)）</li>
+<li>16000：16k（默认）</li>
+<li>8000：8k</li>
+        :rtype: int
+        """
         return self._SampleRate
 
     @SampleRate.setter
@@ -676,6 +817,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def Codec(self):
+        """返回音频格式，可取值：wav（默认），mp3，pcm
+        :rtype: str
+        """
         return self._Codec
 
     @Codec.setter
@@ -684,6 +828,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EnableSubtitle(self):
+        """是否开启时间戳功能，默认为false。
+        :rtype: bool
+        """
         return self._EnableSubtitle
 
     @EnableSubtitle.setter
@@ -692,6 +839,9 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def SegmentRate(self):
+        """断句敏感阈值，默认值为：0，取值范围：[0,1,2]。该值越大越不容易断句，模型会更倾向于仅按照标点符号断句。此参数建议不要随意调整，可能会影响合成效果。
+        :rtype: int
+        """
         return self._SegmentRate
 
     @SegmentRate.setter
@@ -700,6 +850,10 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EmotionCategory(self):
+        """控制合成音频的情感，仅支持多情感音色使用。取值: neutral(中性)、sad(悲伤)、happy(高兴)、angry(生气)、fear(恐惧)、news(新闻)、story(故事)、radio(广播)、poetry(诗歌)、call(客服)、sajiao(撒娇)、disgusted(厌恶)、amaze(震惊)、peaceful(平静)、exciting(兴奋)、aojiao(傲娇)、jieshuo(解说)
+示例值：neutral
+        :rtype: str
+        """
         return self._EmotionCategory
 
     @EmotionCategory.setter
@@ -708,20 +862,15 @@ class TextToVoiceRequest(AbstractModel):
 
     @property
     def EmotionIntensity(self):
+        """控制合成音频情感程度，取值范围为[50,200],默认为100；只有EmotionCategory不为空时生效；
+        :rtype: int
+        """
         return self._EmotionIntensity
 
     @EmotionIntensity.setter
     def EmotionIntensity(self, EmotionIntensity):
         self._EmotionIntensity = EmotionIntensity
 
-    @property
-    def FastVoiceType(self):
-        return self._FastVoiceType
-
-    @FastVoiceType.setter
-    def FastVoiceType(self, FastVoiceType):
-        self._FastVoiceType = FastVoiceType
-
 
     def _deserialize(self, params):
         self._Text = params.get("Text")
@@ -731,6 +880,7 @@ class TextToVoiceRequest(AbstractModel):
         self._ProjectId = params.get("ProjectId")
         self._ModelType = params.get("ModelType")
         self._VoiceType = params.get("VoiceType")
+        self._FastVoiceType = params.get("FastVoiceType")
         self._PrimaryLanguage = params.get("PrimaryLanguage")
         self._SampleRate = params.get("SampleRate")
         self._Codec = params.get("Codec")
@@ -738,7 +888,6 @@ class TextToVoiceRequest(AbstractModel):
         self._SegmentRate = params.get("SegmentRate")
         self._EmotionCategory = params.get("EmotionCategory")
         self._EmotionIntensity = params.get("EmotionIntensity")
-        self._FastVoiceType = params.get("FastVoiceType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             property_name = name[1:]
@@ -772,6 +921,9 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def Audio(self):
+        """base64编码的wav/mp3音频数据
+        :rtype: str
+        """
         return self._Audio
 
     @Audio.setter
@@ -780,6 +932,9 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def SessionId(self):
+        """一次请求对应一个SessionId
+        :rtype: str
+        """
         return self._SessionId
 
     @SessionId.setter
@@ -788,6 +943,9 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def Subtitles(self):
+        """时间戳信息，若未开启时间戳，则返回空数组。
+        :rtype: list of Subtitle
+        """
         return self._Subtitles
 
     @Subtitles.setter
@@ -796,6 +954,9 @@ class TextToVoiceResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
