@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -488,6 +488,9 @@ INVALIDPARAMETERVALUE_SAMPLERATE = 'InvalidParameterValue.SampleRate'
 # 参数值错误：SampleType。
 INVALIDPARAMETERVALUE_SAMPLETYPE = 'InvalidParameterValue.SampleType'
 
+# 场景类型参数取值无效。
+INVALIDPARAMETERVALUE_SCENARIOTYPE = 'InvalidParameterValue.ScenarioType'
+
 # 参数错误：Scheme 无效。
 INVALIDPARAMETERVALUE_SCHEME = 'InvalidParameterValue.Scheme'
 
